<template>
	<div class='widget-wrapper' :style='{...widgetWrapperStyle, ...transitionStyle}'>
        <div class="widget">
            <span class='slashes'>//</span>
			<div
				v-bind:key="index"
				v-for='(object, index) in messages'
				:class='{started: currentMessageIndex >= index, ended: currentMessageIndex > index}'
				class='text-wrapper'
			>
				<span class='text' v-html="object" />
			</div>
        </div>
	</div>
</template>

<script>
import {widgetMixin, positionMixin} from '../helpers/widgets.mjs'

export default {
	mixins: [widgetMixin, positionMixin],

	data() {
		return {
			messages: [],
			intervals: [],
			currentMessageIndex: 0,
		}
	},

	props: {
		chat_id: {
			type: Number,
		},
	},

	created() {
		this.getMessages()

		this.intervals.push(setInterval(this.getMessages, 1000 * 60 * 10))

		this.intervals.push(setInterval(() => {
			this.currentMessageIndex++
			this.currentMessageIndex %= (this.messages.length || 1)
		}, 7 * 1000))
	},

	beforeUnmount() {
		this.intervals.map(clearInterval)
	},

	methods: {
		getMessages() {
			this.act('get_messages', {chat_id: this.chat_id}).then(
				(data) => {
					this.setData(data.data)
					this.messages = this.messages.reverse()
					this.currentMessageIndex = 0
				},
			)
		},
	},

	computed: {
	},
}
</script>

<style scoped>

.widget-wrapper {
	z-index: 1;
}

.widget {
	position: absolute;
    bottom: 3.3%;
    left: 11.5%;
    width: calc(69%);

	font-family: var(--primary-font);
    font-variation-settings: 'wght' 350;
	font-size: .6em;

	color: white;
    opacity: .9;
}

span {
	text-shadow: rgba(0, 0, 0, .15) .1em .1em 0;
}

.text::v-deep a {
	color: white;
    border-bottom: .05em solid white;
    text-decoration: none;
	transition: all .15s ease;
}

.text::v-deep a:hover {
	color: #f41224;
	border-color: #f41224;
	text-shadow: rgba(244, 18, 36, .15) .1em .1em 0;
}

.slashes {
    display: inline-block;

    padding-bottom: .07em;
    font-variation-settings: 'wght' 800;
    opacity: .6;
}

.text-wrapper {
	width: 98%;

    left: 2.5%;

	position: absolute;
	bottom: 1.5em;

    opacity: 0;

	transition: bottom .7s ease;
}

.text-wrapper.started {
	bottom: 0;

    opacity: 1;
    transition: bottom .7s ease, opacity .7s ease;
}

.text-wrapper.ended {
	bottom: -1.5em;
    opacity: 0;
}

.text {
    display: block;

    pointer-events: all;
    user-select: none;

    white-space: nowrap;
    overflow: hidden;
    text-overflow: ellipsis;
}

.text-wrapper:not(.started) .text, .text-wrapper.ended .text {
	pointer-events: none;
}

</style>
